@@ -16,43 +16,43 @@ NULL
 #' }
 #'
 #' @examples
-#'   getSlots("Model")
-#'
+#' getSlots("Model")
 #' @name Model-class
 #' @rdname Model-class
 #' @exportClass Model
 #'
 setClass(
-    Class="Model",
-    representation=representation(
-        listModels = "character",
-        free.proportions = "logical",
-        equal.proportions = "logical",
-        "VIRTUAL"
-    ),
-    prototype=prototype(
-        listModels = character(0),
-        free.proportions = logical(0),
-        equal.proportions = logical(0)
-    )
+  Class = "Model",
+  representation = representation(
+    listModels = "character",
+    free.proportions = "logical",
+    equal.proportions = "logical",
+    "VIRTUAL"
+  ),
+  prototype = prototype(
+    listModels = character(0),
+    free.proportions = logical(0),
+    equal.proportions = logical(0)
+  )
 )
 
 #' @rdname print-methods
 #' @aliases print print,Model-method
 #'
 setMethod(
-  f="print",
-  signature=c("Model"),
-  function(x,...){
+  f = "print",
+  signature = c("Model"),
+  function(x, ...) {
     cat("****************************************\n")
     cat("*** MIXMOD Models:\n")
     cat("* list = ", x@listModels, "\n")
-    if ( x@free.proportions  & x@equal.proportions )
+    if (x@free.proportions & x@equal.proportions) {
       cat("* This list includes models with free and equal proportions.\n")
-    else if ( x@free.proportions  & !x@equal.proportions )
+    } else if (x@free.proportions & !x@equal.proportions) {
       cat("* This list includes only models with free proportions.\n")
-    else if ( !x@free.proportions  & x@equal.proportions )
+    } else if (!x@free.proportions & x@equal.proportions) {
       cat("* This list includes only models with equal proportions.\n")
+    }
     cat("****************************************\n")
   }
 )
@@ -61,18 +61,19 @@ setMethod(
 #' @aliases show show,Model-method
 #'
 setMethod(
-  f="show",
-  signature=c("Model"),
-  function(object){
+  f = "show",
+  signature = c("Model"),
+  function(object) {
     cat("****************************************\n")
     cat("*** MIXMOD Models:\n")
     cat("* list = ", object@listModels, "\n")
-    if ( object@free.proportions  & object@equal.proportions )
-    cat("* This list includes models with free and equal proportions.\n")
-    else if ( object@free.proportions  & !object@equal.proportions )
-    cat("* This list includes only models with free proportions.\n")
-    else if ( !object@free.proportions  & object@equal.proportions )
-    cat("* This list includes only models with equal proportions.\n")
+    if (object@free.proportions & object@equal.proportions) {
+      cat("* This list includes models with free and equal proportions.\n")
+    } else if (object@free.proportions & !object@equal.proportions) {
+      cat("* This list includes only models with free proportions.\n")
+    } else if (!object@free.proportions & object@equal.proportions) {
+      cat("* This list includes only models with equal proportions.\n")
+    }
     cat("****************************************\n")
   }
 )
